"""Loop exercises"""


def get_vowel_names():
    """Return a list containing all names given that start with a vowel."""


def sum_timestamps():
    """Return a timestamp that represents the sum of the input timestamps."""


def product():
    """Returning all given numbers multiplied together."""


def sum_all():
    """Return the sum of all numbers in the given list-of-lists."""


def flatten():
    """Return a flattened version of the given 2-D matrix (list-of-lists)."""


def matrix_from_string():
    """Convert rows of numbers to list of lists."""


def words_containing():
    """Return all words that contain the given letter."""


def are_consecutive(numbers):
    """Return True if numbers are consecutive, else return False."""


if __name__ == "__main__":
    print('To test a specific function, run "python3 test.py <function_name>"')
    print("Alternatively, you can edit this file to write your own assertions")
    # If you'd like, you can put your own assertions here
    # To check these assertions run: python3 functions.py
    # Removing "# " from the lines below will "uncomment" that code

    # assert get_vowel_names(["Alice", "Bob", "Christy", "Jules"]) == ["Alice"]
    # assert get_vowel_names(["Scott", "Arthur", "eda"]) == ["Arthur", "eda"]

    # assert product([5, 6, 8]) == 240
    # assert product([10]) == 10

    # assert sum_all([[1, 2, 3], [4, 5, 6]]) == 21
    # assert sum_all([[0, 1], [4, 2], [3, 1]]) == 11

    # assert flatten([[1, 2], [4, 5], [7, 8]]) == [1, 2, 4, 5, 7, 8]

    # assert words_containing(['Hello', 'there', 'user'], 'r') == ['there', 'user']
    # assert words_containing(['Hello', 'there', 'user'], 'h') == ['Hello', 'there']

    # assert are_consecutive([3, 4, 5, 6])
    # assert not are_consecutive([3, 5, 9])
